# RADICAL-EnsembleToolkit (EnTK)

[![Build Status](https://github.com/radical-cybertools/radical.entk/actions/workflows/python-app.yml/badge.svg)](https://github.com/radical-cybertools/radical.entk/actions/workflows/python-app.yml)
[![codecov](https://codecov.io/gh/radical-cybertools/radical.entk/branch/devel/graph/badge.svg?token=dHn74ChzmX)](https://codecov.io/gh/radical-cybertools/radical.entk)
[![conda](https://anaconda.org/conda-forge/radical.entk/badges/version.svg)](https://anaconda.org/conda-forge/radical.entk)

The documentation for Ensemble Toolkit is available at
[http://radicalentk.readthedocs.io/en/latest/](http://radicalentk.readthedocs.io/en/latest/)
